@@ -33,7 +33,7 @@ function upload_test_images() {
       sed "s@knative.dev/networking@knative.dev/net-istio/vendor/knative.dev/networking@g" $yaml \
         `# ko resolve is being used for the side-effect of publishing images,` \
         `# so the resulting yaml produced is ignored.` \
-        | ko resolve --platform=all ${tag_option} -RBf- > /dev/null
+        | ko resolve --platform=linux/amd64 ${tag_option} -RBf- > /dev/null
     done
   )
 }
